Type: Package
Package: broom
Title: Convert Statistical Objects into Tidy Tibbles
Version: 1.0.13
Authors@R: c(
    person("David", "Robinson", , "admiral.david@gmail.com", role = "aut"),
    person("Alex", "Hayes", , "alexpghayes@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0002-4985-5160")),
    person("Simon", "Couch", , "simon.couch@posit.co", role = c("aut"),
           comment = c(ORCID = "0000-0001-5676-5107")),
    person("Emil", "Hvitfeldt", , "emil.hvitfeldt@posit.co", role = c("aut", "cre"), 
           comment = c(ORCID = "0000-0002-0679-1945")),
    person("Posit Software, PBC", role = c("cph", "fnd"),
           comment = c(ROR = "03wc8by49")),
    person("Indrajeet", "Patil", , "patilindrajeet.science@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0003-1995-6531")),
    person("Derek", "Chiu", , "dchiu@bccrc.ca", role = "ctb"),
    person("Matthieu", "Gomez", , "mattg@princeton.edu", role = "ctb"),
    person("Boris", "Demeshev", , "boris.demeshev@gmail.com", role = "ctb"),
    person("Dieter", "Menne", , "dieter.menne@menne-biomed.de", role = "ctb"),
    person("Benjamin", "Nutter", , "nutter@battelle.org", role = "ctb"),
    person("Luke", "Johnston", , "luke.johnston@mail.utoronto.ca", role = "ctb"),
    person("Ben", "Bolker", , "bolker@mcmaster.ca", role = "ctb"),
    person("Francois", "Briatte", , "f.briatte@gmail.com", role = "ctb"),
    person("Jeffrey", "Arnold", , "jeffrey.arnold@gmail.com", role = "ctb"),
    person("Jonah", "Gabry", , "jsg2201@columbia.edu", role = "ctb"),
    person("Luciano", "Selzer", , "luciano.selzer@gmail.com", role = "ctb"),
    person("Gavin", "Simpson", , "ucfagls@gmail.com", role = "ctb"),
    person("Jens", "Preussner", , "jens.preussner@mpi-bn.mpg.de", role = "ctb"),
    person("Jay", "Hesselberth", , "jay.hesselberth@gmail.com", role = "ctb"),
    person("Hadley", "Wickham", , "hadley@posit.co", role = "ctb"),
    person("Matthew", "Lincoln", , "matthew.d.lincoln@gmail.com", role = "ctb"),
    person("Alessandro", "Gasparini", , "ag475@leicester.ac.uk", role = "ctb"),
    person("Lukasz", "Komsta", , "lukasz.komsta@umlub.pl", role = "ctb"),
    person("Frederick", "Novometsky", role = "ctb"),
    person("Wilson", "Freitas", role = "ctb"),
    person("Michelle", "Evans", role = "ctb"),
    person("Jason Cory", "Brunson", , "cornelioid@gmail.com", role = "ctb"),
    person("Simon", "Jackson", , "drsimonjackson@gmail.com", role = "ctb"),
    person("Ben", "Whalley", , "ben.whalley@plymouth.ac.uk", role = "ctb"),
    person("Karissa", "Whiting", , "karissa.whiting@gmail.com", role = "ctb"),
    person("Yves", "Rosseel", , "yrosseel@gmail.com", role = "ctb"),
    person("Michael", "Kuehn", , "mkuehn10@gmail.com", role = "ctb"),
    person("Jorge", "Cimentada", , "cimentadaj@gmail.com", role = "ctb"),
    person("Erle", "Holgersen", , "erle.holgersen@gmail.com", role = "ctb"),
    person("Karl", "Dunkle Werner", role = "ctb",
           comment = c(ORCID = "0000-0003-0523-7309")),
    person("Ethan", "Christensen", , "christensen.ej@gmail.com", role = "ctb"),
    person("Steven", "Pav", , "shabbychef@gmail.com", role = "ctb"),
    person("Paul", "PJ", , "pjpaul.stephens@gmail.com", role = "ctb"),
    person("Ben", "Schneider", , "benjamin.julius.schneider@gmail.com", role = "ctb"),
    person("Patrick", "Kennedy", , "pkqstr@protonmail.com", role = "ctb"),
    person("Lily", "Medina", , "lilymiru@gmail.com", role = "ctb"),
    person("Brian", "Fannin", , "captain@pirategrunt.com", role = "ctb"),
    person("Jason", "Muhlenkamp", , "jason.muhlenkamp@gmail.com", role = "ctb"),
    person("Matt", "Lehman", role = "ctb"),
    person("Bill", "Denney", , "wdenney@humanpredictions.com", role = "ctb",
           comment = c(ORCID = "0000-0002-5759-428X")),
    person("Nic", "Crane", role = "ctb"),
    person("Andrew", "Bates", role = "ctb"),
    person("Vincent", "Arel-Bundock", , "vincent.arel-bundock@umontreal.ca", role = "ctb",
           comment = c(ORCID = "0000-0003-2042-7063")),
    person("Hideaki", "Hayashi", role = "ctb"),
    person("Luis", "Tobalina", role = "ctb"),
    person("Annie", "Wang", , "anniewang.uc@gmail.com", role = "ctb"),
    person("Wei Yang", "Tham", , "weiyang.tham@gmail.com", role = "ctb"),
    person("Clara", "Wang", , "clara.wang.94@gmail.com", role = "ctb"),
    person("Abby", "Smith", , "als1@u.northwestern.edu", role = "ctb",
           comment = c(ORCID = "0000-0002-3207-0375")),
    person("Jasper", "Cooper", , "jaspercooper@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0002-8639-3188")),
    person("E Auden", "Krauska", , "krauskae@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0002-1466-5850")),
    person("Alex", "Wang", , "x249wang@uwaterloo.ca", role = "ctb"),
    person("Malcolm", "Barrett", , "malcolmbarrett@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0003-0299-5825")),
    person("Charles", "Gray", , "charlestigray@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0002-9978-011X")),
    person("Jared", "Wilber", role = "ctb"),
    person("Vilmantas", "Gegzna", , "GegznaV@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0002-9500-5167")),
    person("Eduard", "Szoecs", , "eduardszoecs@gmail.com", role = "ctb"),
    person("Frederik", "Aust", , "frederik.aust@uni-koeln.de", role = "ctb",
           comment = c(ORCID = "0000-0003-4900-788X")),
    person("Angus", "Moore", , "angusmoore9@gmail.com", role = "ctb"),
    person("Nick", "Williams", , "ntwilliams.personal@gmail.com", role = "ctb"),
    person("Marius", "Barth", , "marius.barth.uni.koeln@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0002-3421-6665")),
    person("Bruna", "Wundervald", , "brunadaviesw@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0001-8163-220X")),
    person("Joyce", "Cahoon", , "joyceyu48@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0001-7217-4702")),
    person("Grant", "McDermott", , "grantmcd@uoregon.edu", role = "ctb",
           comment = c(ORCID = "0000-0001-7883-8573")),
    person("Kevin", "Zarca", , "kevin.zarca@gmail.com", role = "ctb"),
    person("Shiro", "Kuriwaki", , "shirokuriwaki@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0002-5687-2647")),
    person("Lukas", "Wallrich", , "lukas.wallrich@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0003-2121-5177")),
    person("James", "Martherus", , "james@martherus.com", role = "ctb",
           comment = c(ORCID = "0000-0002-8285-3300")),
    person("Chuliang", "Xiao", , "cxiao@umich.edu", role = "ctb",
           comment = c(ORCID = "0000-0002-8466-9398")),
    person("Joseph", "Larmarange", , "joseph@larmarange.net", role = "ctb"),
    person("Max", "Kuhn", , "max@posit.co", role = "ctb"),
    person("Michal", "Bojanowski", , "michal2992@gmail.com", role = "ctb"),
    person("Hakon", "Malmedal", , "hmalmedal@gmail.com", role = "ctb"),
    person("Clara", "Wang", role = "ctb"),
    person("Sergio", "Oller", , "sergioller@gmail.com", role = "ctb"),
    person("Luke", "Sonnet", , "luke.sonnet@gmail.com", role = "ctb"),
    person("Jim", "Hester", , "jim.hester@posit.co", role = "ctb"),
    person("Ben", "Schneider", , "benjamin.julius.schneider@gmail.com", role = "ctb"),
    person("Bernie", "Gray", , "bfgray3@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0001-9190-6032")),
    person("Mara", "Averick", , "mara@posit.co", role = "ctb"),
    person("Aaron", "Jacobs", , "atheriel@gmail.com", role = "ctb"),
    person("Andreas", "Bender", , "bender.at.R@gmail.com", role = "ctb"),
    person("Sven", "Templer", , "sven.templer@gmail.com", role = "ctb"),
    person("Paul-Christian", "Buerkner", , "paul.buerkner@gmail.com", role = "ctb"),
    person("Matthew", "Kay", , "mjskay@umich.edu", role = "ctb"),
    person("Erwan", "Le Pennec", , "lepennec@gmail.com", role = "ctb"),
    person("Johan", "Junkka", , "johan.junkka@umu.se", role = "ctb"),
    person("Hao", "Zhu", , "haozhu233@gmail.com", role = "ctb"),
    person("Benjamin", "Soltoff", , "soltoffbc@uchicago.edu", role = "ctb"),
    person("Zoe", "Wilkinson Saldana", , "zoewsaldana@gmail.com", role = "ctb"),
    person("Tyler", "Littlefield", , "tylurp1@gmail.com", role = "ctb"),
    person("Charles T.", "Gray", , "charlestigray@gmail.com", role = "ctb"),
    person("Shabbh E.", "Banks", role = "ctb"),
    person("Serina", "Robinson", , "robi0916@umn.edu", role = "ctb"),
    person("Roger", "Bivand", , "Roger.Bivand@nhh.no", role = "ctb"),
    person("Riinu", "Ots", , "riinuots@gmail.com", role = "ctb"),
    person("Nicholas", "Williams", , "ntwilliams.personal@gmail.com", role = "ctb"),
    person("Nina", "Jakobsen", role = "ctb"),
    person("Michael", "Weylandt", , "michael.weylandt@gmail.com", role = "ctb"),
    person("Lisa", "Lendway", , "llendway@macalester.edu", role = "ctb"),
    person("Karl", "Hailperin", , "khailper@gmail.com", role = "ctb"),
    person("Josue", "Rodriguez", , "jerrodriguez@ucdavis.edu", role = "ctb"),
    person("Jenny", "Bryan", , "jenny@posit.co", role = "ctb"),
    person("Chris", "Jarvis", , "Christopher1.jarvis@gmail.com", role = "ctb"),
    person("Greg", "Macfarlane", , "gregmacfarlane@gmail.com", role = "ctb"),
    person("Brian", "Mannakee", , "bmannakee@gmail.com", role = "ctb"),
    person("Drew", "Tyre", , "atyre2@unl.edu", role = "ctb"),
    person("Shreyas", "Singh", , "shreyas.singh.298@gmail.com", role = "ctb"),
    person("Laurens", "Geffert", , "laurensgeffert@gmail.com", role = "ctb"),
    person("Hong", "Ooi", , "hongooi@microsoft.com", role = "ctb"),
    person("Henrik", "Bengtsson", , "henrikb@braju.com", role = "ctb"),
    person("Eduard", "Szocs", , "eduardszoecs@gmail.com", role = "ctb"),
    person("David", "Hugh-Jones", , "davidhughjones@gmail.com", role = "ctb"),
    person("Matthieu", "Stigler", , "Matthieu.Stigler@gmail.com", role = "ctb"),
    person("Hugo", "Tavares", , "hm533@cam.ac.uk", role = "ctb",
           comment = c(ORCID = "0000-0001-9373-2726")),
    person("R. Willem", "Vervoort", , "Willemvervoort@gmail.com", role = "ctb"),
    person("Brenton M.", "Wiernik", , "brenton@wiernik.org", role = "ctb"),
    person("Josh", "Yamamoto", , "joshuayamamoto5@gmail.com", role = "ctb"),
    person("Jasme", "Lee", role = "ctb"),
    person("Taren", "Sanders", , "taren.sanders@acu.edu.au", role = "ctb",
           comment = c(ORCID = "0000-0002-4504-6008")),
    person("Ilaria", "Prosdocimi", , "prosdocimi.ilaria@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0001-8565-094X")),
    person("Daniel D.", "Sjoberg", , "danield.sjoberg@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0003-0862-2018")),
    person("Alex", "Reinhart", , "areinhar@stat.cmu.edu", role = "ctb",
           comment = c(ORCID = "0000-0002-6658-514X"))
  )
Description: Summarizes key information about statistical objects in tidy
    tibbles. This makes it easy to report results, create plots and
    consistently work with large numbers of models at once.  Broom
    provides three verbs that each provide different types of information
    about a model. tidy() summarizes information about model components
    such as coefficients of a regression. glance() reports information
    about an entire model, such as goodness of fit measures like AIC and
    BIC. augment() adds information about individual observations to a
    dataset, such as fitted values or influence measures.
License: MIT + file LICENSE
URL: https://broom.tidymodels.org/, https://github.com/tidymodels/broom
BugReports: https://github.com/tidymodels/broom/issues
Depends: R (>= 4.1)
Imports: backports, cli, dplyr (>= 1.0.0), generics (>= 0.0.2), glue,
        lifecycle, purrr, rlang (>= 1.1.0), stringr, tibble (>= 3.0.0),
        tidyr (>= 1.0.0)
Suggests: AER, AUC, bbmle, betareg (>= 3.2-1), biglm, binGroup, boot,
        btergm (>= 1.10.6), car (>= 3.1-2), carData, caret, cluster,
        cmprsk, coda, covr, drc, e1071, emmeans, epiR (>= 2.0.85), ergm
        (>= 3.10.4), fixest (>= 0.9.0), gam (>= 1.15), gee, geepack,
        ggplot2, glmnet, glmnetUtils, gmm, Hmisc, interp, irlba,
        joineRML, Kendall, knitr, ks, Lahman, lavaan (>= 0.6.18),
        leaps, lfe, lm.beta, lme4, lmodel2, lmtest (>= 0.9.38),
        lsmeans, maps, margins, MASS, mclust, mediation, metafor, mfx,
        mgcv, mlogit, modeldata, modeltests (>= 0.1.6), muhaz,
        multcomp, network, nnet, ordinal, plm, poLCA, psych, quantreg,
        rmarkdown, robust, robustbase, rsample, sandwich, spatialreg,
        spdep (>= 1.1), speedglm, spelling, stats4, survey, survival
        (>= 3.6-4), systemfit, testthat (>= 3.0.0), tseries, vars, zoo
VignetteBuilder: knitr
Config/Needs/website: tidyverse/tidytemplate
Config/testthat/edition: 3
Config/usethis/last-upkeep: 2025-04-25
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
Collate: 'aaa-documentation-helper.R' 'null-and-default.R' 'aer.R'
        'auc.R' 'base.R' 'bbmle.R' 'betareg.R' 'biglm.R' 'bingroup.R'
        'boot.R' 'broom-package.R' 'broom.R' 'btergm.R' 'car.R'
        'caret.R' 'cluster.R' 'cmprsk.R' 'data-frame.R'
        'deprecated-0-7-0.R' 'drc.R' 'emmeans.R' 'epiR.R' 'ergm.R'
        'fixest.R' 'gam.R' 'geepack.R' 'glmnet-cv-glmnet.R'
        'glmnet-glmnet.R' 'gmm.R' 'hmisc.R'
        'import-standalone-obj-type.R'
        'import-standalone-types-check.R' 'joinerml.R' 'kendall.R'
        'ks.R' 'lavaan.R' 'leaps.R' 'lfe.R' 'list-irlba.R'
        'list-optim.R' 'list-svd.R' 'list-xyz.R' 'list.R' 'lm-beta.R'
        'lmodel2.R' 'lmtest.R' 'maps.R' 'margins.R' 'mass-fitdistr.R'
        'mass-negbin.R' 'mass-polr.R' 'mass-ridgelm.R' 'stats-lm.R'
        'mass-rlm.R' 'mclust.R' 'mediation.R' 'metafor.R' 'mfx.R'
        'mgcv.R' 'mlogit.R' 'muhaz.R' 'multcomp.R' 'nnet.R' 'nobs.R'
        'ordinal-clm.R' 'ordinal-clmm.R' 'plm.R' 'polca.R' 'psych.R'
        'stats-nls.R' 'quantreg-nlrq.R' 'quantreg-rq.R'
        'quantreg-rqs.R' 'robust-glmrob.R' 'robust-lmrob.R'
        'robustbase-glmrob.R' 'robustbase-lmrob.R' 'sp.R' 'spdep.R'
        'speedglm-speedglm.R' 'speedglm-speedlm.R' 'stats-anova.R'
        'stats-arima.R' 'stats-decompose.R' 'stats-factanal.R'
        'stats-glm.R' 'stats-htest.R' 'stats-kmeans.R' 'stats-loess.R'
        'stats-mlm.R' 'stats-prcomp.R' 'stats-smooth.spline.R'
        'stats-summary-lm.R' 'stats-time-series.R' 'survey.R'
        'survival-aareg.R' 'survival-cch.R' 'survival-coxph.R'
        'survival-pyears.R' 'survival-survdiff.R' 'survival-survexp.R'
        'survival-survfit.R' 'survival-survreg.R' 'systemfit.R'
        'tseries.R' 'utilities.R' 'vars.R' 'zoo.R' 'zzz.R'
NeedsCompilation: no
Packaged: 2026-05-13 23:36:34 UTC; emilhvitfeldt
Author: David Robinson [aut],
  Alex Hayes [aut] (ORCID: <https://orcid.org/0000-0002-4985-5160>),
  Simon Couch [aut] (ORCID: <https://orcid.org/0000-0001-5676-5107>),
  Emil Hvitfeldt [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0679-1945>),
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>),
  Indrajeet Patil [ctb] (ORCID: <https://orcid.org/0000-0003-1995-6531>),
  Derek Chiu [ctb],
  Matthieu Gomez [ctb],
  Boris Demeshev [ctb],
  Dieter Menne [ctb],
  Benjamin Nutter [ctb],
  Luke Johnston [ctb],
  Ben Bolker [ctb],
  Francois Briatte [ctb],
  Jeffrey Arnold [ctb],
  Jonah Gabry [ctb],
  Luciano Selzer [ctb],
  Gavin Simpson [ctb],
  Jens Preussner [ctb],
  Jay Hesselberth [ctb],
  Hadley Wickham [ctb],
  Matthew Lincoln [ctb],
  Alessandro Gasparini [ctb],
  Lukasz Komsta [ctb],
  Frederick Novometsky [ctb],
  Wilson Freitas [ctb],
  Michelle Evans [ctb],
  Jason Cory Brunson [ctb],
  Simon Jackson [ctb],
  Ben Whalley [ctb],
  Karissa Whiting [ctb],
  Yves Rosseel [ctb],
  Michael Kuehn [ctb],
  Jorge Cimentada [ctb],
  Erle Holgersen [ctb],
  Karl Dunkle Werner [ctb] (ORCID:
    <https://orcid.org/0000-0003-0523-7309>),
  Ethan Christensen [ctb],
  Steven Pav [ctb],
  Paul PJ [ctb],
  Ben Schneider [ctb],
  Patrick Kennedy [ctb],
  Lily Medina [ctb],
  Brian Fannin [ctb],
  Jason Muhlenkamp [ctb],
  Matt Lehman [ctb],
  Bill Denney [ctb] (ORCID: <https://orcid.org/0000-0002-5759-428X>),
  Nic Crane [ctb],
  Andrew Bates [ctb],
  Vincent Arel-Bundock [ctb] (ORCID:
    <https://orcid.org/0000-0003-2042-7063>),
  Hideaki Hayashi [ctb],
  Luis Tobalina [ctb],
  Annie Wang [ctb],
  Wei Yang Tham [ctb],
  Clara Wang [ctb],
  Abby Smith [ctb] (ORCID: <https://orcid.org/0000-0002-3207-0375>),
  Jasper Cooper [ctb] (ORCID: <https://orcid.org/0000-0002-8639-3188>),
  E Auden Krauska [ctb] (ORCID: <https://orcid.org/0000-0002-1466-5850>),
  Alex Wang [ctb],
  Malcolm Barrett [ctb] (ORCID: <https://orcid.org/0000-0003-0299-5825>),
  Charles Gray [ctb] (ORCID: <https://orcid.org/0000-0002-9978-011X>),
  Jared Wilber [ctb],
  Vilmantas Gegzna [ctb] (ORCID: <https://orcid.org/0000-0002-9500-5167>),
  Eduard Szoecs [ctb],
  Frederik Aust [ctb] (ORCID: <https://orcid.org/0000-0003-4900-788X>),
  Angus Moore [ctb],
  Nick Williams [ctb],
  Marius Barth [ctb] (ORCID: <https://orcid.org/0000-0002-3421-6665>),
  Bruna Wundervald [ctb] (ORCID: <https://orcid.org/0000-0001-8163-220X>),
  Joyce Cahoon [ctb] (ORCID: <https://orcid.org/0000-0001-7217-4702>),
  Grant McDermott [ctb] (ORCID: <https://orcid.org/0000-0001-7883-8573>),
  Kevin Zarca [ctb],
  Shiro Kuriwaki [ctb] (ORCID: <https://orcid.org/0000-0002-5687-2647>),
  Lukas Wallrich [ctb] (ORCID: <https://orcid.org/0000-0003-2121-5177>),
  James Martherus [ctb] (ORCID: <https://orcid.org/0000-0002-8285-3300>),
  Chuliang Xiao [ctb] (ORCID: <https://orcid.org/0000-0002-8466-9398>),
  Joseph Larmarange [ctb],
  Max Kuhn [ctb],
  Michal Bojanowski [ctb],
  Hakon Malmedal [ctb],
  Clara Wang [ctb],
  Sergio Oller [ctb],
  Luke Sonnet [ctb],
  Jim Hester [ctb],
  Ben Schneider [ctb],
  Bernie Gray [ctb] (ORCID: <https://orcid.org/0000-0001-9190-6032>),
  Mara Averick [ctb],
  Aaron Jacobs [ctb],
  Andreas Bender [ctb],
  Sven Templer [ctb],
  Paul-Christian Buerkner [ctb],
  Matthew Kay [ctb],
  Erwan Le Pennec [ctb],
  Johan Junkka [ctb],
  Hao Zhu [ctb],
  Benjamin Soltoff [ctb],
  Zoe Wilkinson Saldana [ctb],
  Tyler Littlefield [ctb],
  Charles T. Gray [ctb],
  Shabbh E. Banks [ctb],
  Serina Robinson [ctb],
  Roger Bivand [ctb],
  Riinu Ots [ctb],
  Nicholas Williams [ctb],
  Nina Jakobsen [ctb],
  Michael Weylandt [ctb],
  Lisa Lendway [ctb],
  Karl Hailperin [ctb],
  Josue Rodriguez [ctb],
  Jenny Bryan [ctb],
  Chris Jarvis [ctb],
  Greg Macfarlane [ctb],
  Brian Mannakee [ctb],
  Drew Tyre [ctb],
  Shreyas Singh [ctb],
  Laurens Geffert [ctb],
  Hong Ooi [ctb],
  Henrik Bengtsson [ctb],
  Eduard Szocs [ctb],
  David Hugh-Jones [ctb],
  Matthieu Stigler [ctb],
  Hugo Tavares [ctb] (ORCID: <https://orcid.org/0000-0001-9373-2726>),
  R. Willem Vervoort [ctb],
  Brenton M. Wiernik [ctb],
  Josh Yamamoto [ctb],
  Jasme Lee [ctb],
  Taren Sanders [ctb] (ORCID: <https://orcid.org/0000-0002-4504-6008>),
  Ilaria Prosdocimi [ctb] (ORCID:
    <https://orcid.org/0000-0001-8565-094X>),
  Daniel D. Sjoberg [ctb] (ORCID:
    <https://orcid.org/0000-0003-0862-2018>),
  Alex Reinhart [ctb] (ORCID: <https://orcid.org/0000-0002-6658-514X>)
Maintainer: Emil Hvitfeldt <emil.hvitfeldt@posit.co>
Repository: CRAN
Date/Publication: 2026-05-14 05:10:21 UTC
Built: R 4.5.2; ; 2026-05-14 06:47:15 UTC; unix
