#' Allowed argument names in tidiers
#'
#' @format A tibble with 3 variables:
#' \describe{
#' \item{method}{One of "glance", "augment" or "tidy".}
#' \item{argument}{Character name of allowed argument name.}
#' \item{description}{Character description of argument use.}
#' }
#' @examples
#' argument_glossary
"argument_glossary"
