# tidy.default

    Code
      td <- tidy(raw(1))
    Condition
      Error in `tidy()`:
      ! No `tidy()` method for objects of class <raw>.

---

    Code
      glance(x)
    Condition
      Error in `glance()`:
      ! No `glance()` method for objects of class <foo/bar>.

---

    Code
      glance(x)
    Condition
      Error in `glance()`:
      ! No `glance()` method for objects of class <foo/bar>.

# glance.default

    Code
      glance(TRUE)
    Condition
      Error in `glance()`:
      ! No `glance()` method for objects of class <logical>.

---

    Code
      glance(1)
    Condition
      Error in `glance()`:
      ! No `glance()` method for objects of class <numeric>.

---

    Code
      glance(1L)
    Condition
      Error in `glance()`:
      ! No `glance()` method for objects of class <integer>.

---

    Code
      glance("a")
    Condition
      Error in `glance()`:
      ! No `glance()` method for objects of class <character>.

---

    Code
      glance(x)
    Condition
      Error in `glance()`:
      ! No `glance()` method for objects of class <foo/bar>.

---

    Code
      glance(x)
    Condition
      Error in `glance()`:
      ! No `glance()` method for objects of class <foo/bar>.

# augment.default

    Code
      augment(TRUE)
    Condition
      Error in `augment()`:
      ! No `augment()` method for objects of class <logical>.

---

    Code
      augment(1)
    Condition
      Error in `augment()`:
      ! No `augment()` method for objects of class <numeric>.

---

    Code
      augment(1L)
    Condition
      Error in `augment()`:
      ! No `augment()` method for objects of class <integer>.

---

    Code
      augment("a")
    Condition
      Error in `augment()`:
      ! No `augment()` method for objects of class <character>.

---

    Code
      augment(x)
    Condition
      Error in `augment()`:
      ! No `augment()` method for objects of class <foo/bar>.

---

    Code
      augment(x)
    Condition
      Error in `augment()`:
      ! No `augment()` method for objects of class <foo/bar>.

